Installation
============

1. Setup Python 3.4 or above; versions 2.x are not supported.

2. Create and activate a "virtual environment" for Python 3 as follows::

	# All platforms.
	> python -m venv pyenv
	
	# Windows.
	> pyenv/Scripts/activate.bat
	# Posix.
	> source pyenv/bin/activate

3. Install this tool from PIP directly with this short command::

	> pip install nuclai
	
4. Test the script to make sure everything works as expected::

	> nuclai help

Usage
=====

	> nuclai install <package>
